@@ -96,6 +96,7 @@ class BaseRegistry(meta.with_metaclass(_Meta)):
     :param on_redefinition: action to take in case a unit is redefined.
                             'warn', 'raise', 'ignore'
     :type on_redefinition: str
+    :param auto_reduce_dimensions: If True, reduce dimensionality on appropriate operations.
     """
 
     #: Map context prefix to function
@@ -111,7 +112,7 @@ class BaseRegistry(meta.with_metaclass(_Meta)):
             'parse_unit_name', 'parse_units', 'parse_expression',
             'convert']
 
-    def __init__(self, filename='', force_ndarray=False, on_redefinition='warn'):
+    def __init__(self, filename='', force_ndarray=False, on_redefinition='warn', auto_reduce_dimensions=False):
 
         self._register_parsers()
 
@@ -129,6 +130,9 @@ class BaseRegistry(meta.with_metaclass(_Meta)):
         #: Action to take in case a unit is redefined. 'warn', 'raise', 'ignore'
         self._on_redefinition = on_redefinition
 
+        #: Determines if dimensionality should be reduced on appropriate operations.
+        self.auto_reduce_dimensions = auto_reduce_dimensions
+
         #: Map between name (string) and value (string) of defaults stored in the definitions file.
         self._defaults = {}
 
@@ -935,6 +939,11 @@ class NonMultiplicativeRegistry(BaseRegistry):
         src_dim = self._get_dimensionality(src)
         dst_dim = self._get_dimensionality(dst)
 
+        # If the source and destination dimensionality are different,
+        # then the conversion cannot be performed.
+        if src_dim != dst_dim:
+            raise DimensionalityError(src, dst, src_dim, dst_dim)
+
         # For offset units we need to check if the conversion is allowed.
         if src_offset_units or dst_offset_units:
 
@@ -1435,17 +1444,20 @@ class UnitRegistry(SystemRegistry, ContextRegistry, NonMultiplicativeRegistry):
     :param on_redefinition: action to take in case a unit is redefined.
                             'warn', 'raise', 'ignore'
     :type on_redefinition: str
+    :param auto_reduce_dimensions: If True, reduce dimensionality on appropriate operations.
     """
 
     def __init__(self, filename='', force_ndarray=False, default_as_delta=True,
                  autoconvert_offset_to_baseunit=False,
-                 on_redefinition='warn', system=None):
+                 on_redefinition='warn', system=None,
+                 auto_reduce_dimensions=False):
 
         super(UnitRegistry, self).__init__(filename=filename, force_ndarray=force_ndarray,
                                            on_redefinition=on_redefinition,
                                            default_as_delta=default_as_delta,
                                            autoconvert_offset_to_baseunit=autoconvert_offset_to_baseunit,
-                                           system=system)
+                                           system=system,
+                                           auto_reduce_dimensions=auto_reduce_dimensions)
 
     def pi_theorem(self, quantities):
         """Builds dimensionless quantities using the Buckingham π theorem
